yakumo.session.SessionProxy

Package yakumo :: Module session :: Class SessionProxy |
[hide private]
[frames] | no frames]

# Class SessionProxy

source code

    object --+
             |
            SessionProxy

Instance Methods | [hide private]
__init__(self, session, service) x.__init__(...) initializes x; see help(type(x)) for signature | source code
has_endpoint(self, service) | source code
get(self, *args, **kwargs) | source code
head(self, *args, **kwargs) | source code
delete(self, *args, **kwargs) | source code
patch(self, *args, **kwargs) | source code
post(self, *args, **kwargs) | source code
put(self, *args, **kwargs) | source code
get_raw(self, *args, **kwargs) | source code
post_raw(self, *args, **kwargs) | source code
put_raw(self, *args, **kwargs) | source code
get_file(self, *args, **kwargs) | source code
post_file(self, *args, **kwargs) | source code
put_file(self, *args, **kwargs) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, session, service) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)